<div class="flex flex-col gap-4">
  <c-lb.alert variant="info" direction="vertical" icon="rmx.information">
    <div>
      <h3 class="font-bold">Vertical Alert</h3>
      <div class="text-xs">This is a vertical layout alert</div>
    </div>
  </c-lb.alert>

  <c-lb.alert variant="success" direction="horizontal" icon="rmx.check">
    <div>
      <h3 class="font-bold">Horizontal Alert</h3>
      <div class="text-xs">This is a horizontal layout alert</div>
    </div>
  </c-lb.alert>
</div>
