<div class="flex flex-col gap-4">
  <c-lb.alert variant="info">
    <span>We use cookies for analytics.</span>
    <c-slot name="actions">
      <button class="btn btn-sm">Accept</button>
    </c-slot>
  </c-lb.alert>

  <c-lb.alert variant="warning">
    <span>This action cannot be undone.</span>
    <c-slot name="actions">
      <button class="btn btn-sm btn-warning">Dismiss</button>
    </c-slot>
  </c-lb.alert>

  <c-lb.alert variant="error">
    <span>Failed to save changes.</span>
    <c-slot name="actions">
      <button class="btn btn-sm btn-error">Retry</button>
      <button class="btn btn-sm btn-ghost">Cancel</button>
    </c-slot>
  </c-lb.alert>
</div>
