<div class="flex flex-col gap-2">
    <label class="label">
        <c-lb.checkbox />
        Remember me
    </label>

    <label class="label">
        <c-lb.checkbox variant="primary" disabled checked />
        Accept terms and conditions
    </label>

    <label class="label">
        <c-lb.checkbox variant="success" checked />
        Subscribe to newsletter
    </label>
</div>
