<div class="w-full">
    <c-lb.navbar class="bg-base-100 border border-base-200 rounded-box">
        <c-lb.navbar.start>
            <c-lb.button btnStyle="ghost" size="sm">
                <c-lbi n="rmx.apps" w="1em" h="1em" />
                Brand
            </c-lb.button>
        </c-lb.navbar.start>
        <c-lb.navbar.center class="hidden lg:flex">
            <c-lb.button btnStyle="ghost" size="sm">
                <c-lbi n="rmx.home" w="1em" h="1em" />
                Home
            </c-lb.button>
            <c-lb.button btnStyle="ghost" size="sm">
                <c-lbi n="rmx.info-i" w="1em" h="1em" />
                About
            </c-lb.button>
            <c-lb.button btnStyle="ghost" size="sm">
                <c-lbi n="rmx.mail" w="1em" h="1em" />
                Contact
            </c-lb.button>
        </c-lb.navbar.center>
        <c-lb.navbar.end>
            <c-lb.button btnStyle="ghost" size="sm" class="lg:hidden">
                <c-lbi n="rmx.menu" w="1em" h="1em" />
                Menu
            </c-lb.button>
            <c-lb.button btnStyle="ghost" size="sm" class="hidden lg:flex">
                <c-lbi n="rmx.login-box" w="1em" h="1em" />
                Login
            </c-lb.button>
        </c-lb.navbar.end>
    </c-lb.navbar>
</div>
