<div class="flex flex-wrap gap-2">
  <c-lb.badge variant="primary" icon="rmx.star">Unfilled Star</c-lb.badge>
  <c-lb.badge variant="primary" icon="rmx.star" iconFill>Filled Star</c-lb.badge>
  <c-lb.badge variant="success" icon="rmx.heart">Unfilled Heart</c-lb.badge>
  <c-lb.badge variant="success" icon="rmx.heart" iconFill>Filled Heart</c-lb.badge>
  <c-lb.badge variant="warning" icon="rmx.check">Unfilled Check</c-lb.badge>
  <c-lb.badge variant="warning" icon="rmx.check" iconFill>Filled Check</c-lb.badge>
</div>
