{% load static %}

<div class="flex items-center gap-4">
  <c-lb.avatar
    ring="true"
    ringColor="primary"
    rounded="full"
    src="{% static 'lbdocs/img/stock/avatar.png' %}"
    alt="Avatar with primary ring" />
  <c-lb.avatar
    ring="true"
    ringColor="success"
    rounded="full"
    src="{% static 'lbdocs/img/stock/avatar.png' %}"
    alt="Avatar with success ring" />
</div>
