<c-lb.button variant="primary" onclick="responsive_modal.showModal()">Open Responsive Modal</c-lb.button>

<c-lb.modal id="responsive_modal" placement="bottom" class="sm:modal-middle" boxClass="shadow">
    <h3 class="text-lg font-bold">Responsive Modal</h3>
    <p class="py-4">This modal goes bottom on small screens, middle on medium screens and up</p>
    <c-lb.modal.action boxClass="shadow">
        <form method="dialog">
            <c-lb.button>Close</c-lb.button>
        </form>
    </c-lb.modal.action>
</c-lb.modal>
