{% load static %}

<c-lb.avatar.group>
  <c-lb.avatar size="sm" src="{% static 'lbdocs/img/stock/avatar.png' %}" alt="User 1" />
  <c-lb.avatar size="sm" src="{% static 'lbdocs/img/stock/avatar.png' %}" alt="User 2" />
  <c-lb.avatar size="sm" src="{% static 'lbdocs/img/stock/avatar.png' %}" alt="User 3" />
  <c-lb.avatar size="sm" placeholder initials="+99" bgColor="neutral" />
</c-lb.avatar.group>
