<div class="flex flex-wrap gap-2">
  <c-lb.badge variant="info" icon="rmx.information">Info</c-lb.badge>
  <c-lb.badge variant="success" icon="rmx.check">Success</c-lb.badge>
  <c-lb.badge variant="warning" icon="rmx.error_warning">Warning</c-lb.badge>
  <c-lb.badge variant="error" icon="rmx.close">Error</c-lb.badge>
  <c-lb.badge variant="primary" icon="rmx.star">Featured</c-lb.badge>
  <c-lb.badge variant="secondary" icon="rmx.heart">Favorite</c-lb.badge>
</div>
