<div class="flex items-center gap-4">
  <c-lb.swap inputClass="theme-controller" value="light">
    <c-lb.swap.on class="flex items-center gap-2">
        <c-lbi n="rmx.sun" w="1.5em" h="1.5em" />
        <span class="text-sm">daisyUI Light Theme</span>
    </c-lb.swap.on>
    <c-lb.swap.off class="flex items-center gap-2">
      <c-lbi n="rmx.moon" w="1.5em" h="1.5em" />
      <span class="text-sm">Default Theme</span>
    </c-lb.swap.off>
  </c-lb.swap>
</div>
