<p class="text-sm text-gray-600 mb-4">Look at the screen corner bottom right.</p>

<c-lb.fab variant="primary" size="lg" label="B">
    <c-lb.button variant="neutral" size="lg" modifier="circle">B</c-lb.button>
    <c-lb.button variant="neutral" size="lg" modifier="circle">A</c-lb.button>
    <c-lb.button variant="neutral" size="lg" modifier="circle">L</c-lb.button>
</c-lb.fab>
