<div class="flex flex-col gap-4">
  <div class="flex items-center gap-2">
    <c-lb.toggle disabled />
    <span class="text-sm">Disabled (unchecked)</span>
  </div>
  <div class="flex items-center gap-2">
    <c-lb.toggle disabled checked />
    <span class="text-sm">Disabled (checked)</span>
  </div>
</div>
