<div class="flex flex-wrap items-center gap-2">
  <c-lb.badge variant="primary" size="xs" icon="rmx.star">Extra Small</c-lb.badge>
  <c-lb.badge variant="primary" size="sm" icon="rmx.star">Small</c-lb.badge>
  <c-lb.badge variant="primary" size="md" icon="rmx.star">Medium</c-lb.badge>
  <c-lb.badge variant="primary" size="lg" icon="rmx.star">Large</c-lb.badge>
  <c-lb.badge variant="primary" size="xl" icon="rmx.star">Extra Large</c-lb.badge>
</div>
