<div class="flex items-center gap-4">
  <span class="text-sm">Default</span>
  <c-lb.toggle class="theme-controller" value="light" size="sm" />
  <span class="text-sm">daisyUI Light Mode</span>
</div>
