<c-lb.dropdown>
    <c-lb.dropdown.trigger class="btn m-1">Card Content</c-lb.dropdown.trigger>
    <c-lb.dropdown.content class="card card-sm bg-base-100 z-1 w-64 shadow-sm">
        <c-lb.card.body>
            <h2 class="card-title">Dropdown Card</h2>
            <p>This is a card used as dropdown content. You can use any element as a dropdown.</p>
            <c-lb.card.actions>
                <c-lb.button variant="primary">Action</c-lb.button>
            </c-lb.card.actions>
        </c-lb.card.body>
    </c-lb.dropdown.content>
</c-lb.dropdown>
