{% load static %}

<div class="flex items-center gap-4">
  <c-lb.avatar status="online" rounded="full" src="{% static 'lbdocs/img/stock/avatar.png' %}" alt="Online user" />
  <c-lb.avatar status="offline" rounded="full" src="{% static 'lbdocs/img/stock/avatar.png' %}" alt="Offline user" />
</div>
