<div class="flex items-center gap-4">
  <c-lb.avatar placeholder>
    <div class="w-24 rounded-full bg-gradient-to-r from-purple-500 to-pink-500">
      <c-lbi n="rmx.star" w="1.5rem" h="1.5rem" class="text-white" fill="true" />
    </div>
  </c-lb.avatar>

  <c-lb.avatar placeholder>
    <div class="w-24 rounded-full bg-base-200 text-2xl font-bold">
      🎨
    </div>
  </c-lb.avatar>
</div>
