<c-lb.tabs name="boxed_tabs" style="box">
    <c-lb.tabs.content name="boxed_tabs" title="Tab 1" checked class="mt-2 bg-base-100 rounded-lg p-6 lg:min-w-60">
        <p>Boxed tab content</p>
    </c-lb.tabs.content>
    <c-lb.tabs.content name="boxed_tabs" title="Tab 2" class="mt-2 bg-base-100 rounded-lg p-6 lg:min-w-60">
        <p>Another boxed tab content</p>
    </c-lb.tabs.content>
</c-lb.tabs>
