<div class="flex flex-col gap-4">
  <c-lb.alert variant="info" icon="rmx.star" iconFill><span>Filled star icon</span></c-lb.alert>
  <c-lb.alert variant="success" icon="rmx.heart" iconFill><span>Filled heart icon</span></c-lb.alert>
  <c-lb.alert variant="warning" icon="rmx.thumb-up" iconFill><span>Filled thumb up icon</span></c-lb.alert>
  <c-lb.alert variant="error" icon="rmx.flag" iconFill><span>Filled flag icon</span></c-lb.alert>
</div>
