<div class="flex flex-wrap gap-2 items-center">
  <c-lb.button size="xs">Extra Small</c-lb.button>
  <c-lb.button size="sm">Small</c-lb.button>
  <c-lb.button size="md">Medium</c-lb.button>
  <c-lb.button size="lg">Large</c-lb.button>
  <c-lb.button size="xl">Extra Large</c-lb.button>
</div>
