<div class="relative h-72">
    <c-lb.fab variant="info" size="lg" class="absolute bottom-4 right-4" label="F">
        <c-lb.fab.close variant="error">×</c-lb.fab.close>
        <div>Label A <c-lb.button variant="neutral" size="lg" modifier="circle">A</c-lb.button></div>
        <div>Label B <c-lb.button variant="neutral" size="lg" modifier="circle">B</c-lb.button></div>
        <div>Label C <c-lb.button variant="neutral" size="lg" modifier="circle">C</c-lb.button></div>
    </c-lb.fab>
</div>
