<c-lb.dropdown hover>
    <c-lb.dropdown.trigger class="btn m-1">Hover me</c-lb.dropdown.trigger>
    <c-lb.dropdown.content class="bg-base-100 rounded-box w-52 p-2 shadow-sm">
        <c-lb.menu class="w-full">
            <c-lb.menu.item>Item 1</c-lb.menu.item>
            <c-lb.menu.item>Item 2</c-lb.menu.item>
            <c-lb.menu.item>Item 3</c-lb.menu.item>
        </c-lb.menu>
    </c-lb.dropdown.content>
</c-lb.dropdown>
