<div class="flex gap-4 flex-wrap items-center">
    <c-lb.checkbox size="xs" checked />
    <c-lb.checkbox size="sm" checked />
    <c-lb.checkbox size="md" checked />
    <c-lb.checkbox size="lg" checked />
    <c-lb.checkbox size="xl" checked />
</div>
