<c-vars
    class=""
    size=""
    :sizeClasses="{
        'xs': 'w-72 max-w-xs',
        'sm': 'w-80 max-w-sm',
        'md': 'w-96 max-w-md',
        'lg': 'w-[32rem] max-w-lg',
        'xl': 'w-[36rem] max-w-xl',
        'screen': 'w-11/12 max-w-5xl'
    }"
/>

<div
    class="modal-box {% if size %}{{ sizeClasses|get_item:size }}{% endif %} {{ class }}"
    {{ attrs }}
>
    {{ slot }}
</div>
