<c-lb.accordion join class="bg-base-100">
    <c-lb.accordion.item name="joined-accordion" title="How do I create an account?" checked join border>
        <p class="text-sm">Click the "Sign Up" button in the top right corner and follow the registration process.</p>
    </c-lb.accordion.item>
    <c-lb.accordion.item name="joined-accordion" title="I forgot my password. What should I do?" join border>
        <p class="text-sm">Click on "Forgot Password" on the login page and follow the instructions sent to your email.</p>
    </c-lb.accordion.item>
    <c-lb.accordion.item name="joined-accordion" title="How do I update my profile information?" join border>
        <p class="text-sm">Go to "My Account" settings and select "Edit Profile" to make changes.</p>
    </c-lb.accordion.item>
</c-lb.accordion>
