<c-lb.drawer drawerId="default-slot-drawer">
  <div class="flex flex-col items-center justify-center p-4">
    <h2 class="text-2xl font-bold mb-4">Default Slot Only</h2>
    <p class="mb-4">This drawer only uses the default slot - no sidebar.</p>
    <c-lb.button variant="primary">Simple Button</c-lb.button>
  </div>
</c-lb.drawer>
