<div class="flex flex-wrap gap-2">
  <c-lb.badge variant="primary" icon="rmx.star"></c-lb.badge>
  <c-lb.badge variant="success" icon="rmx.check"></c-lb.badge>
  <c-lb.badge variant="warning" icon="rmx.error_warning"></c-lb.badge>
  <c-lb.badge variant="error" icon="rmx.close"></c-lb.badge>
  <c-lb.badge variant="info" icon="rmx.information"></c-lb.badge>
  <c-lb.badge variant="secondary" icon="rmx.heart"></c-lb.badge>
</div>
