<div class="relative h-72">
    <c-lb.fab variant="info" size="lg" flower icon="rmx.add" class="absolute bottom-4 right-4">
        <c-lb.button variant="neutral" size="lg" modifier="circle">
            <c-lbi n="rmx.camera" w="1em" h="1em" />
        </c-lb.button>
        <c-lb.button variant="neutral" size="lg" modifier="circle">
            <c-lbi n="rmx.image" w="1em" h="1em" />
        </c-lb.button>
        <c-lb.button variant="neutral" size="lg" modifier="circle">
            <c-lbi n="rmx.mic" w="1em" h="1em" />
        </c-lb.button>
        <c-lb.button variant="neutral" size="lg" modifier="circle">
            <c-lbi n="rmx.upload" w="1em" h="1em" />
        </c-lb.button>
    </c-lb.fab>
</div>
