<div class="space-y-6">
  <div>
    <h4 class="text-sm font-medium mb-2">Small Tabs</h4>
    <c-lb.tabs name="small_tabs" style="lift" size="sm">
        <c-lb.tabs.content name="small_tabs" title="Tab 1" checked class="border-base-300 bg-base-100 p-4 lg:min-w-60">
            <p>Small tab content</p>
        </c-lb.tabs.content>
        <c-lb.tabs.content name="small_tabs" title="Tab 2" class="border-base-300 bg-base-100 p-4 lg:min-w-60">
            <p>Another small tab content</p>
        </c-lb.tabs.content>
    </c-lb.tabs>
  </div>

  <div>
    <h4 class="text-sm font-medium mb-2">Large Tabs</h4>
    <c-lb.tabs name="large_tabs" style="lift" size="lg">
        <c-lb.tabs.content name="large_tabs" title="Tab 1" checked class="border-base-300 bg-base-100 p-8 lg:min-w-60">
            <p>Large tab content</p>
        </c-lb.tabs.content>
        <c-lb.tabs.content name="large_tabs" title="Tab 2" class="border-base-300 bg-base-100 p-8 lg:min-w-60">
            <p>Another large tab content</p>
        </c-lb.tabs.content>
    </c-lb.tabs>
  </div>
</div>
