<div class="space-y-6">
  <div>
    <h4 class="text-sm font-medium mb-2">Small Table</h4>
    <div class="overflow-x-auto bg-base-100 rounded-lg shadow p-4 border border-base-200">
        <c-lb.table size="sm">
            <thead>
                <tr>
                    <th>#</th>
                    <th>Name</th>
                    <th>Job</th>
                </tr>
            </thead>
            <tbody>
                <tr>
                    <th>1</th>
                    <td>Cy Ganderton</td>
                    <td>Quality Control</td>
                </tr>
            </tbody>
        </c-lb.table>
    </div>
  </div>

  <div>
    <h4 class="text-sm font-medium mb-2">Large Table</h4>
    <div class="overflow-x-auto bg-base-100 rounded-lg shadow p-4 border border-base-200">
        <c-lb.table size="lg">
            <thead>
                <tr>
                    <th>#</th>
                    <th>Name</th>
                    <th>Job</th>
                </tr>
            </thead>
            <tbody>
                <tr>
                    <th>1</th>
                    <td>Cy Ganderton</td>
                    <td>Quality Control Specialist</td>
                </tr>
            </tbody>
        </c-lb.table>
    </div>
  </div>
</div>
