<div class="flex flex-col gap-4">
  <c-lb.alert variant="success" icon="rmx.check" class="shadow-lg">
    <div><strong>Success!</strong> Your changes have been saved successfully.</div>
    <c-slot name="actions">
      <button class="btn btn-sm btn-success">Continue</button>
    </c-slot>
  </c-lb.alert>

  <c-lb.alert variant="error" icon="rmx.close-circle" class="border-2">
    <div><strong>Error:</strong> Failed to connect to the server. Please try again.</div>
    <c-slot name="actions">
      <button class="btn btn-sm btn-error">Retry</button>
      <button class="btn btn-sm btn-ghost">Cancel</button>
    </c-slot>
  </c-lb.alert>

  <c-lb.alert variant="warning" icon="rmx.alert" class="bg-warning/10">
    <div><strong>Warning:</strong> This action cannot be undone.</div>
    <c-slot name="actions">
      <button class="btn btn-sm btn-warning">Dismiss</button>
    </c-slot>
  </c-lb.alert>
</div>
