<c-lb.tabs name="icon_tabs" style="lift" class="lg:max-w-[80%] mx-auto">
    <c-lb.tabs.content name="icon_tabs" title="Home" checked icon="rmx.home" class="border-base-300 bg-base-100 p-6 min-w-full">
        <h3 class="text-lg font-semibold mb-2">Home Content</h3>
        <p>This is the home tab content with a home icon.</p>
    </c-lb.tabs.content>
    <c-lb.tabs.content name="icon_tabs" title="Settings" icon="rmx.settings" class="border-base-300 bg-base-100 p-6 min-w-full">
        <h3 class="text-lg font-semibold mb-2">Settings Content</h3>
        <p>This is the settings tab content with a settings icon.</p>
    </c-lb.tabs.content>
    <c-lb.tabs.content name="icon_tabs" title="Profile" icon="rmx.user" class="border-base-300 bg-base-100 p-6 min-w-full">
        <h3 class="text-lg font-semibold mb-2">Profile Content</h3>
        <p>This is the profile tab content with a user icon.</p>
    </c-lb.tabs.content>
    <c-lb.tabs.content name="icon_tabs" title="Messages" icon="rmx.message" iconFill class="border-base-300 bg-base-100 p-6 min-w-full">
        <h3 class="text-lg font-semibold mb-2">Messages Content</h3>
        <p>This is the messages tab content with a filled message icon.</p>
    </c-lb.tabs.content>
</c-lb.tabs>
