<c-lb.card variant="accent" class="shadow-lg w-full max-w-2xl">
  <c-lb.card.figure class="px-10 pt-10">
    <div class="avatar placeholder">
      <div class="bg-neutral text-neutral-content rounded-full w-24">
        <span class="text-3xl">🚀</span>
      </div>
    </div>
  </c-lb.card.figure>

  <c-lb.card.body class="items-center text-center">
    <c-lb.card.title class="text-2xl">Welcome to Labb Components!</c-lb.card.title>
    <p class="text-lg mb-6">Build beautiful Django interfaces with our modern component library. Everything you need to create professional web applications.</p>

    <div class="flex flex-wrap gap-2 justify-center">
      <div class="badge badge-outline">Django Cotton</div>
      <div class="badge badge-outline">DaisyUI 5</div>
      <div class="badge badge-outline">Tailwind CSS</div>
      <div class="badge badge-outline">Accessible</div>
    </div>
  </c-lb.card.body>
</c-lb.card>
