<div class="flex flex-col gap-4">
  <c-lb.alert variant="info" style="outline"><span>Outline style alert</span></c-lb.alert>
  <c-lb.alert variant="success" style="dash"><span>Dash style alert</span></c-lb.alert>
  <c-lb.alert variant="warning" style="soft"><span>Soft style alert</span></c-lb.alert>
  <c-lb.alert variant="error" style="outline"><span>Error with outline style</span></c-lb.alert>
</div>
