<div class="flex flex-wrap gap-2">
  <c-lb.badge variant="info">
    <c-lbi n="rmx.information" w="1em" h="1em" />
    Info
  </c-lb.badge>
  <c-lb.badge variant="success">
    <c-lbi n="rmx.check" w="1em" h="1em" />
    Success
  </c-lb.badge>
  <c-lb.badge variant="warning">
    <c-lbi n="rmx.error-warning" w="1em" h="1em" />
    Warning
  </c-lb.badge>
  <c-lb.badge variant="error">
    <c-lbi n="rmx.close" w="1em" h="1em" />
    Error
  </c-lb.badge>
</div>
