<div class="flex items-center gap-4">
  <c-lb.avatar placeholder initials="JD" bgColor="neutral" rounded="full" />
  <c-lb.avatar placeholder initials="AI" bgColor="primary" rounded="full" status="online" size="sm" />
  <c-lb.avatar placeholder icon="rmx.user" bgColor="accent" rounded="full" size="lg" />
  <c-lb.avatar placeholder icon="rmx.admin" iconFill="true" bgColor="success" rounded="full" />
</div>
