<div class="flex flex-wrap items-center gap-2">
  <c-lb.badge variant="primary" size="xs">Extra Small</c-lb.badge>
  <c-lb.badge variant="primary" size="sm">Small</c-lb.badge>
  <c-lb.badge variant="primary" size="md">Medium</c-lb.badge>
  <c-lb.badge variant="primary" size="lg">Large</c-lb.badge>
  <c-lb.badge variant="primary" size="xl">Extra Large</c-lb.badge>
</div>
