<c-lb.drawer drawerId="submenu-drawer" sideClass="z-99">
  <c-slot name="sideContent">
    <div class="p-4 h-full bg-base-200 w-64">
      <h3 class="text-lg font-semibold mb-4">With Submenus</h3>
      <c-lb.menu class="bg-base-200 text-base-content rounded-box w-full">
        <c-lb.menu.item title="Dashboard" />
        <c-lb.menu.item type="submenu-details" title="Products" open>
          <c-lb.menu.item title="All Products" />
          <c-lb.menu.item title="Categories" />
          <c-lb.menu.item title="Inventory" />
        </c-lb.menu.item>
        <c-lb.menu.item type="submenu-details" title="Users">
          <c-lb.menu.item title="All Users" />
          <c-lb.menu.item title="Roles" />
          <c-lb.menu.item title="Permissions" />
        </c-lb.menu.item>
        <c-lb.menu.item title="Settings" />
      </c-lb.menu>
    </div>
  </c-slot>

  <div class="flex flex-col items-center justify-center p-4">
    <c-lb.drawer.toggle for="submenu-drawer" class="btn btn-accent">
      Open with Submenus
    </c-lb.drawer.toggle>
  </div>
</c-lb.drawer>
