<c-vars
    class=""
    justify=""
    :justifyClasses="{
        'start': 'justify-start',
        'center': 'justify-center',
        'end': 'justify-end',
        'between': 'justify-between',
        'around': 'justify-around',
        'evenly': 'justify-evenly'
    }"
/>

<div
    class="card-actions {{ justifyClasses|get_item:justify }} {{ class }}"
    {{ attrs }}
>
    {{ slot }}
</div>
