<div class="relative h-72">
    <c-lb.fab variant="success" size="lg" class="absolute bottom-4 right-4" label="F">
        <c-lb.fab.main-action variant="secondary">M</c-lb.fab.main-action>
    </c-lb.fab>
</div>
