<div class="flex flex-wrap gap-2">
  <c-lb.button btnStyle="outline">Outline</c-lb.button>
  <c-lb.button btnStyle="dash">Dash</c-lb.button>
  <c-lb.button btnStyle="soft">Soft</c-lb.button>
  <c-lb.button btnStyle="ghost">Ghost</c-lb.button>
  <c-lb.button btnStyle="link">Link</c-lb.button>
</div>
