<div class="flex flex-col gap-4">
  <div class="flex items-center gap-2">
    <c-lb.toggle size="xs" />
    <span class="text-sm">Extra Small</span>
  </div>
  <div class="flex items-center gap-2">
    <c-lb.toggle size="sm" />
    <span class="text-sm">Small</span>
  </div>
  <div class="flex items-center gap-2">
    <c-lb.toggle size="md" />
    <span class="text-sm">Medium (default)</span>
  </div>
  <div class="flex items-center gap-2">
    <c-lb.toggle size="lg" />
    <span class="text-sm">Large</span>
  </div>
  <div class="flex items-center gap-2">
    <c-lb.toggle size="xl" />
    <span class="text-sm">Extra Large</span>
  </div>
</div>
