<div class="space-y-4">
  <div>
    <h4 class="text-sm font-medium mb-2">Button Element (Default)</h4>
    <c-lb.button>Button Element</c-lb.button>
  </div>

  <div>
    <h4 class="text-sm font-medium mb-2">Anchor Element</h4>
    <c-lb.button as="a" href="#example">Link Button</c-lb.button>
  </div>

  <div>
    <h4 class="text-sm font-medium mb-2">Input Element</h4>
    <c-lb.button as="input" type="submit" value="Submit Input" />
  </div>

  <div>
    <h4 class="text-sm font-medium mb-2">Div Element</h4>
    <c-lb.button as="div">Div Button</c-lb.button>
  </div>
</div>
