<div class="flex flex-wrap gap-2">
  <c-lb.button btnStyle="outline" variant="neutral">Neutral</c-lb.button>
  <c-lb.button btnStyle="outline" variant="primary">Primary</c-lb.button>
  <c-lb.button btnStyle="outline" variant="secondary">Secondary</c-lb.button>
  <c-lb.button btnStyle="outline" variant="accent">Accent</c-lb.button>
  <c-lb.button btnStyle="outline" variant="info">Info</c-lb.button>
  <c-lb.button btnStyle="outline" variant="success">Success</c-lb.button>
  <c-lb.button btnStyle="outline" variant="warning">Warning</c-lb.button>
  <c-lb.button btnStyle="outline" variant="error">Error</c-lb.button>
</div>
