<c-lb.menu class="bg-base-100 rounded-box w-64 shadow">
    <c-lb.menu.item type="title" title="Navigation" />
    <c-lb.menu.item href="/" title="Home" />
    <c-lb.menu.item href="/about" title="About" />

    <c-lb.menu.item type="title" title="Account" />
    <c-lb.menu.item href="/profile" title="Profile" />
    <c-lb.menu.item href="/settings" title="Settings" />
    <c-lb.menu.item href="/logout" title="Logout" />
</c-lb.menu>
