<div class="flex flex-wrap items-center gap-2">
  <c-lb.badge variant="primary" size="lg"></c-lb.badge>
  <c-lb.badge variant="primary" size="md"></c-lb.badge>
  <c-lb.badge variant="primary" size="sm"></c-lb.badge>
  <c-lb.badge variant="primary" size="xs"></c-lb.badge>
</div>
