<div class="flex flex-col gap-4">
  <c-lb.alert variant="info" icon="rmx.information"></c-lb.alert>
  <c-lb.alert variant="success" icon="rmx.check"></c-lb.alert>
  <c-lb.alert variant="warning" icon="rmx.alert"></c-lb.alert>
  <c-lb.alert variant="error" icon="rmx.close-circle"></c-lb.alert>
</div>
