<div class="flex flex-wrap gap-2">
  <c-lb.badge variant="primary">Default</c-lb.badge>
  <c-lb.badge variant="primary" style="outline">Outline</c-lb.badge>
  <c-lb.badge variant="primary" style="dash">Dash</c-lb.badge>
  <c-lb.badge variant="primary" style="soft">Soft</c-lb.badge>
  <c-lb.badge variant="primary" style="ghost">Ghost</c-lb.badge>
</div>
