<c-vars
    class=""
    style=""
    placement="top"
    size="md"
    name="tabs"
    :styleClasses="{
        'border': 'tabs-border',
        'lift': 'tabs-lift',
        'box': 'tabs-box'
    }"
    :placementClasses="{
        'top': '',
        'bottom': 'tabs-bottom'
    }"
    :sizeClasses="{
        'xs': 'tabs-xs',
        'sm': 'tabs-sm',
        'md': 'tabs-md',
        'lg': 'tabs-lg',
        'xl': 'tabs-xl'
    }"
/>

<div
    class="tabs {{ styleClasses|get_item:style }} {{ placementClasses|get_item:placement }} {{ sizeClasses|get_item:size }} {{ class }}"
    {{ attrs }}
>
    {% if not content %}
        {{ slot }}
    {% else %}
        {{ content }}
    {% endif %}
</div>
