<c-lb.tabs name="basic_tabs" style="lift">
    <c-lb.tabs.content name="basic_tabs" title="Live" checked class="border-base-300 bg-base-100 p-6 lg:min-w-60">
        <h3 class="text-lg font-semibold mb-2">Live Content</h3>
        <p>This is the live tab content with some example text.</p>
    </c-lb.tabs.content>
    <c-lb.tabs.content name="basic_tabs" title="Laugh" class="border-base-300 bg-base-100 p-6 lg:min-w-60">
        <h3 class="text-lg font-semibold mb-2">Laugh Content</h3>
        <p>This is the laugh tab content with some example text.</p>
    </c-lb.tabs.content>
    <c-lb.tabs.content name="basic_tabs" title="Love" class="border-base-300 bg-base-100 p-6 lg:min-w-60">
        <h3 class="text-lg font-semibold mb-2">Love Content</h3>
        <p>This is the love tab content with some example text.</p>
    </c-lb.tabs.content>
</c-lb.tabs>
