<c-lb.swap effect="rotate">
    <c-lb.swap.on>
        <c-lbi n="rmx.sun" w="2em" h="2em" />
    </c-lb.swap.on>
    <c-lb.swap.off>
        <c-lbi n="rmx.moon" w="2em" h="2em" />
    </c-lb.swap.off>
</c-lb.swap>
