<c-vars
    class=""
    variant=""
    :variantClasses="{
        'neutral': 'badge-neutral',
        'primary': 'badge-primary',
        'secondary': 'badge-secondary',
        'accent': 'badge-accent',
        'info': 'badge-info',
        'success': 'badge-success',
        'warning': 'badge-warning',
        'error': 'badge-error'
    }"
    style=""
    :styleClasses="{
        'outline': 'badge-outline',
        'dash': 'badge-dash',
        'soft': 'badge-soft',
        'ghost': 'badge-ghost'
    }"
    size="md"
    :sizeClasses="{
        'xs': 'badge-xs',
        'sm': 'badge-sm',
        'md': 'badge-md',
        'lg': 'badge-lg',
        'xl': 'badge-xl'
    }"
    icon=""
    iconFill
    iconClass=""
/>

<span class="badge {{ variantClasses|get_item:variant }} {{ styleClasses|get_item:style }} {{ sizeClasses|get_item:size }} {{ class }}" {{ attrs }}>
    {% if icon %}
        <c-component is="lbi" n="{{ icon }}" w="1em" h="1em" :fill=iconFill :class=iconClass />
    {% endif %}
    {{ slot }}
</span>
