<c-lb.swap effect="rotate" class="btn btn-circle">
    <c-lb.swap.on>
        <c-lbi n="rmx.close" w="1.5em" h="1.5em" />
    </c-lb.swap.on>
    <c-lb.swap.off>
        <c-lbi n="rmx.menu" w="1.5em" h="1.5em" />
    </c-lb.swap.off>
</c-lb.swap>
