<c-lb.menu direction="horizontal" class="bg-base-100 rounded-box w-full shadow">
    <c-lb.menu.item href="/" title="Home" />
    <c-lb.menu.item href="/about" title="About" />
    <c-lb.menu.item href="/services" title="Services" />
    <c-lb.menu.item href="/contact" title="Contact" />
</c-lb.menu>
