<div class="flex flex-col gap-4">
  <c-lb.alert variant="info" icon="rmx.information"><span>Information message with icon</span></c-lb.alert>
  <c-lb.alert variant="success" icon="rmx.check"><span>Success message with icon</span></c-lb.alert>
  <c-lb.alert variant="warning" icon="rmx.alert"><span>Warning message with icon</span></c-lb.alert>
  <c-lb.alert variant="error" icon="rmx.close-circle"><span>Error message with icon</span></c-lb.alert>
</div>
