<div class="flex flex-col gap-4">
  <div class="flex items-center gap-2">
    <c-lb.toggle variant="primary" checked />
    <span class="text-sm">Primary</span>
  </div>
  <div class="flex items-center gap-2">
    <c-lb.toggle variant="secondary" checked />
    <span class="text-sm">Secondary</span>
  </div>
  <div class="flex items-center gap-2">
    <c-lb.toggle variant="accent" checked />
    <span class="text-sm">Accent</span>
  </div>
  <div class="flex items-center gap-2">
    <c-lb.toggle variant="neutral" checked />
    <span class="text-sm">Neutral</span>
  </div>
  <div class="flex items-center gap-2">
    <c-lb.toggle variant="info" checked />
    <span class="text-sm">Info</span>
  </div>
  <div class="flex items-center gap-2">
    <c-lb.toggle variant="success" checked />
    <span class="text-sm">Success</span>
  </div>
  <div class="flex items-center gap-2">
    <c-lb.toggle variant="warning" checked />
    <span class="text-sm">Warning</span>
  </div>
  <div class="flex items-center gap-2">
    <c-lb.toggle variant="error" checked />
    <span class="text-sm">Error</span>
  </div>
</div>
