<div class="flex gap-4 flex-wrap">
    <c-lb.checkbox variant="primary" checked />
    <c-lb.checkbox variant="secondary" checked />
    <c-lb.checkbox variant="accent" checked />
    <c-lb.checkbox variant="neutral" checked />
    <c-lb.checkbox variant="info" checked />
    <c-lb.checkbox variant="success" checked />
    <c-lb.checkbox variant="warning" checked />
    <c-lb.checkbox variant="error" checked />
</div>
