<c-lb.button variant="primary" onclick="corner_close_modal.showModal()">Open Modal</c-lb.button>

<c-lb.modal id="corner_close_modal" withCloseBtn boxClass="shadow">
    <h3 class="text-lg font-bold">Hello!</h3>
    <p class="py-4">Press ESC key or click on ✕ button to close</p>
</c-lb.modal>
