{% load static %}

<c-lb.card side border class="bg-base-100 shadow-sm">
  <c-lb.card.figure>
    <img src="{% static 'lbdocs/img/stock/mecca.jpg' %}" alt="Movie" />
  </c-lb.card.figure>
  <c-lb.card.body>
    <c-lb.card.title>Visit Mecca!</c-lb.card.title>
    <p>Click the button to visit Mecca.</p>
    <c-lb.card.actions justify="end">
      <c-lb.button variant="secondary">Visit </c-lb.button>
    </c-lb.card.actions>
  </c-lb.card.body>
</c-lb.card>
