<c-vars
    class=""
    variant="secondary"
    size="lg"
    :variantClasses="{
        'neutral': 'btn-neutral',
        'primary': 'btn-primary',
        'secondary': 'btn-secondary',
        'accent': 'btn-accent',
        'info': 'btn-info',
        'success': 'btn-success',
        'warning': 'btn-warning',
        'error': 'btn-error'
    }"
    :sizeClasses="{
        'xs': 'btn-xs',
        'sm': 'btn-sm',
        'md': 'btn-md',
        'lg': 'btn-lg',
        'xl': 'btn-xl'
    }"
/>

<div class="fab-main-action {{ class }}" {{ attrs }}>
    <button class="btn btn-circle {{ sizeClasses|get_item:size }} {{ variantClasses|get_item:variant }}">{{ slot }}</button>
</div>
