<c-lb.tabs name="lift_tabs" style="lift">
    <c-lb.tabs.content name="lift_tabs" title="Tab 1" checked class="border-base-300 bg-base-100 p-6 lg:min-w-60">
        <p>Lift tab content</p>
    </c-lb.tabs.content>
    <c-lb.tabs.content name="lift_tabs" title="Tab 2" class="border-base-300 bg-base-100 p-6 lg:min-w-60">
        <p>Another lift tab content</p>
    </c-lb.tabs.content>
</c-lb.tabs>
