<div class="relative h-72">
    <c-lb.fab variant="primary" size="lg" class="absolute bottom-4 right-4">
        <div tabindex="0" role="button" class="btn btn-circle btn-primary btn-lg">
            <c-lbi.rmx.settings w="1em" h="1em" />
        </div>
        <c-lb.button variant="neutral" size="lg" modifier="circle">A</c-lb.button>
        <c-lb.button variant="neutral" size="lg" modifier="circle">B</c-lb.button>
        <c-lb.button variant="neutral" size="lg" modifier="circle">C</c-lb.button>
    </c-lb.fab>
</div>
