{% load static %}

<div class="flex items-center gap-4">
  <c-lb.avatar size="xs" src="{% static 'lbdocs/img/stock/avatar.png' %}" alt="Extra small avatar" />
  <c-lb.avatar size="sm" src="{% static 'lbdocs/img/stock/avatar.png' %}" alt="Small avatar" />
  <c-lb.avatar size="md" src="{% static 'lbdocs/img/stock/avatar.png' %}" alt="Medium avatar" />
  <c-lb.avatar size="lg" src="{% static 'lbdocs/img/stock/avatar.png' %}" alt="Large avatar" />
  <c-lb.avatar size="xl" src="{% static 'lbdocs/img/stock/avatar.png' %}" alt="Extra large avatar" />
</div>
