<div class="w-full">
    <c-lb.navbar class="bg-base-100 border border-base-200 rounded-box">
        <c-lb.navbar.start>
            <c-lb.button btnStyle="ghost" size="lg">Brand</c-lb.button>
            <c-lb.button btnStyle="ghost" size="sm" class="hidden lg:flex">Home</c-lb.button>
            <c-lb.button btnStyle="ghost" size="sm" class="hidden lg:flex">About</c-lb.button>
        </c-lb.navbar.start>
        <c-lb.navbar.center>
        </c-lb.navbar.center>
        <c-lb.navbar.end>
            <c-lb.button btnStyle="ghost" size="sm" class="lg:hidden">Menu</c-lb.button>
        </c-lb.navbar.end>
    </c-lb.navbar>
</div>
