<c-vars
    class=""
    variant=""
    :variantClasses="{
        'primary': 'toggle-primary',
        'secondary': 'toggle-secondary',
        'accent': 'toggle-accent',
        'neutral': 'toggle-neutral',
        'info': 'toggle-info',
        'success': 'toggle-success',
        'warning': 'toggle-warning',
        'error': 'toggle-error'
    }"
    size="md"
    :sizeClasses="{
        'xs': 'toggle-xs',
        'sm': 'toggle-sm',
        'md': 'toggle-md',
        'lg': 'toggle-lg',
        'xl': 'toggle-xl'
    }"
    checked
    disabled
/>

<input
    type="checkbox"
    class="toggle {{ variantClasses|get_item:variant }} {{ sizeClasses|get_item:size }} {{ class }}"
    {% if checked %}checked{% endif %}
    {% if disabled %}disabled{% endif %}
    {{ attrs }}
/>
