{% load static %}

<div class="flex items-center gap-4">
  <c-lb.avatar mask="heart" src="{% static 'lbdocs/img/stock/avatar.png' %}" alt="Heart mask avatar" />
  <c-lb.avatar mask="squircle" src="{% static 'lbdocs/img/stock/avatar.png' %}" alt="Squircle mask avatar" />
  <c-lb.avatar mask="hexagon-2" src="{% static 'lbdocs/img/stock/avatar.png' %}" alt="Hexagon mask avatar" />
</div>
