<c-lb.card dash variant="primary" class="w-96">
  <c-lb.card.body>
    <c-lb.card.title>Card Title</c-lb.card.title>
    <p>A card component has a figure, a body part, and inside body there are title and actions parts</p>
    <c-lb.card.actions justify="end">
      <c-lb.button variant="secondary">Buy Now</c-lb.button>
    </c-lb.card.actions>
  </c-lb.card.body>
</c-lb.card>
