<div class="h-64 max-w-100 mx-auto bg-base-100 rounded-lg shadow p-4 overflow-auto border border-base-200">
    <c-lb.table pinRows pinCols size="sm">
        <thead>
            <tr>
                <th>#</th>
                <th>Name</th>
                <th>Job</th>
                <th>Favorite Color</th>
                <th>Department</th>
                <th>Salary</th>
                <th>Location</th>
            </tr>
        </thead>
        <tbody>
            <tr>
                <th>1</th>
                <td>Cy Ganderton</td>
                <td>Quality Control Specialist</td>
                <td>Blue</td>
                <td>Engineering</td>
                <td>$75,000</td>
                <td>New York</td>
            </tr>
            <tr>
                <th>2</th>
                <td>Hart Hagerty</td>
                <td>Desktop Support Technician</td>
                <td>Purple</td>
                <td>IT Support</td>
                <td>$55,000</td>
                <td>Chicago</td>
            </tr>
            <tr>
                <th>3</th>
                <td>Brice Swyre</td>
                <td>Tax Accountant</td>
                <td>Red</td>
                <td>Finance</td>
                <td>$65,000</td>
                <td>Los Angeles</td>
            </tr>
            <tr>
                <th>4</th>
                <td>Marjy Ferencz</td>
                <td>Office Assistant I</td>
                <td>Green</td>
                <td>Administration</td>
                <td>$45,000</td>
                <td>Houston</td>
            </tr>
            <tr>
                <th>5</th>
                <td>Yancy Tear</td>
                <td>Community Outreach Specialist</td>
                <td>Yellow</td>
                <td>Marketing</td>
                <td>$60,000</td>
                <td>Phoenix</td>
            </tr>
            <tr>
                <th>6</th>
                <td>Irma Vasilik</td>
                <td>Editor</td>
                <td>Orange</td>
                <td>Content</td>
                <td>$70,000</td>
                <td>Philadelphia</td>
            </tr>
            <tr>
                <th>7</th>
                <td>Meghann Durtnal</td>
                <td>Staff Accountant IV</td>
                <td>Pink</td>
                <td>Finance</td>
                <td>$80,000</td>
                <td>San Antonio</td>
            </tr>
            <tr>
                <th>8</th>
                <td>Sammy Seston</td>
                <td>Accountant I</td>
                <td>Indigo</td>
                <td>Finance</td>
                <td>$50,000</td>
                <td>San Diego</td>
            </tr>
            <tr>
                <th>9</th>
                <td>Lesya Tinham</td>
                <td>Safety Technician IV</td>
                <td>Teal</td>
                <td>Operations</td>
                <td>$55,000</td>
                <td>Dallas</td>
            </tr>
            <tr>
                <th>10</th>
                <td>Zaneta Tewkesbury</td>
                <td>VP Marketing</td>
                <td>Gray</td>
                <td>Marketing</td>
                <td>$120,000</td>
                <td>San Jose</td>
            </tr>
        </tbody>
    </c-lb.table>
</div>
