<c-lb.menu class="bg-base-100 rounded-box w-64 shadow">
    <c-lb.menu.item href="/" title="Home" />
    <c-lb.menu.item href="/about" title="About" />
    <c-lb.menu.item type="submenu-details" title="Services">
        <c-lb.menu.item href="/web-design" title="Web Design" />
        <c-lb.menu.item href="/development" title="Development" />
        <c-lb.menu.item type="submenu-details" title="Consulting">
            <c-lb.menu.item href="/strategy" title="Strategy" />
            <c-lb.menu.item href="/implementation" title="Implementation" />
            <c-lb.menu.item href="/support" title="Support" />
        </c-lb.menu.item>
    </c-lb.menu.item>
    <c-lb.menu.item href="/contact" title="Contact" />
</c-lb.menu>
