<div class="flex flex-col gap-4">
  <c-lb.alert variant="info"><span>Info Alert</span></c-lb.alert>
  <c-lb.alert variant="success"><span>Success Alert</span></c-lb.alert>
  <c-lb.alert variant="warning"><span>Warning Alert</span></c-lb.alert>
  <c-lb.alert variant="error"><span>Error Alert</span></c-lb.alert>
</div>
